%NUM2ALFCOUNT
% text = num2alfcount(num) Helper function that converts a number from
% 0 to 675 = 26^2-1 into a two letter code: 'aa' for 0, 'ab' for 1,
% 'ac' for 2, etc.
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

function text = num2alfcount(num)
    validate_num(num)
    first_letter = 'a' + floor(num/26);
    second_letter = 'a' + mod(num, 26);
    text = char([first_letter second_letter]);
end

function validate_num(num)
    maxval = 26^2 - 1;
    if numel(num) ~= 1
        error('input must be a scalar value.');
    end

    errmsg = sprintf(['input must be an integer between 0 and %d '...
            '(extremes included).'], maxval);
        
    if isreal(num) == false
        error('%s', errmsg);% input must be a real value
    else
        if mod(num, 1) ~= 0
            error('%s', errmsg);  % input must be an integer
        else
            if (num < 0) || (num > maxval) 
                error('%s', errmsg); % input must be between 0 and 675
            end
        end
    end
end