function prepare_all_2mass
%PREPARE_ALL_2MASS
% Function built to run all functions needed to prepare data from 2MASS
% star catalog sources.
% Before running this function, the user must configure folders and
% directories in "load_2mass_settings.m".
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

t1 = tic;

% First check if all folders are properly set in "load_2mass_settings.m".
conf = load_2mass_settings();
check_2mass_settings(conf);

endmsg = 'See file "01readme.txt" for instructions.';

% Checks the existence of the folder with preprocessed catalog sections
if exist(conf.PSC_mat_path, 'dir') == 0
    error(['Folder "%s", with preprocessed catalog sections, ' ...
        'not found!\n' endmsg], conf.PSC_mat_path);
end

% Checks the existence of the folder used to store processed catalog
% sections
if exist(conf.PSC_sortcat_path, 'dir') == 0
    error(['Folder "%s" not found!\n' ...
        'A place to store catalog sections sorted by magnitude' ...
        ' is needed!\n' endmsg], conf.PSC_sortcat_path);
end


% % % Preprocess star catalog
fprintf('Preprocessing 2-MASS star catalog\n');
convert_all_psc();

% Process star catalog, generating sorted versions of 2MASS star catalog
fprintf('\nSorting 2-MASS star catalog by J, H, Ks magnitudes:\n');
sort_2mass_JHK();

fprintf('\nSorting 2-MASS star catalog by J, H, Ks magnitudes:\n');
sort_2mass_HKJ();


fprintf('Total elapsed time in %s is %f seconds\n', mfilename, toc(t1));
end

