function numstars = sort_2mass_HKJ
%numstars = sort_2mass_HKJ
% sorts the 2-MASS star catalog by H, K_s and J magnitudes, declination,
% and right ascension, in that order of priority.
% Saves the sorted catalog in 20 sections, each roughly the same size.
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

t_start = tic;

conf = load_2mass_settings;
check_2mass_paths(conf);

% If running GNU-Octave, sets default format to use in .mat files
setup_octave_savemat();

numstars = 0;

magfilter_H = [...
    -inf,...
    12.111, 13.020, 13.553, 13.933, 14.230,...
    14.474, 14.683, 14.866, 15.027, 15.171,...
    15.301, 15.418, 15.526, 15.625, 15.718,...
    15.811, 15.909, 16.020, 16.171, +inf];

nsections = size(magfilter_H, 2) - 1;
for k=1:nsections
    t1 = tic;
    section_name = sprintf('psc_HKJ%.2d', k);
    fprintf('Extracting section %d (%s) from 2MASS with %f < H <= %f\n',...
        k, section_name, magfilter_H(k), magfilter_H(k+1));
    
    % Extracts and sorts section by H, Ks, J magnitudes:
    eval([section_name ...
        ' = sort_2mass_HKJ_sub(conf, magfilter_H(k), magfilter_H(k+1));']);
    
    % Information:
    n = eval(['size(' section_name ', 1);']);
    numstars = numstars + n;
    fprintf('%d stars in this H magnitude range.\n', n);
    
    % Saves catalog section ordered by H, Ks, J magnitudes:
    file_HKJ = [conf.PSC_sortcat_path section_name '.mat'];
    fprintf('Saving section %d to file %s\n', k, file_HKJ);
    eval(['save (''' file_HKJ ''', ''' section_name ''');']);
    
    % Cleanup and message
    eval(['clear ' section_name]);
    fprintf('Processing section %d took %f seconds.\n\n', k, toc(t1));
end

fprintf('%d stars processed.\n', numstars);
fprintf('Time spent in %s = %f seconds.\n', mfilename, toc(t_start));

end