% starcat = sort_2mass_JHK_sub(conf, min_mag, max_mag)
% Helper function used to extract all stars in the 2MASS catalog with J
% magnitudes in the range min_magJ < J <= max_magJ
% Sorts extracted entries first by J magnitudes, then, if equal,
% by H magnitudes, then, if still equal, by K magnitudes, then,
% if still equal, by declination and finally, if still equal,
% by right ascension.
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

function starcat = sort_2mass_JHK_sub(conf, min_magJ, max_magJ)

t_init = tic;

starcat=zeros(0,5);

fprintf('Extracting all stars in 2MASS with %f < J magnitude <= %f\n',...
    min_magJ, max_magJ);

% 57 sections in the southern hemisphere
for k=0:56
    basename = ['psc_a' num2alfcount(k)];
    fprintf(' Processing %s', basename);
    cat_section = do_process(conf, basename, min_magJ, max_magJ);
    starcat = [starcat; cat_section]; %#ok<AGROW>
    clear ('cat_section');
end

% 35 sections in the northern hemisphere
for k=0:34
    basename = ['psc_b' num2alfcount(k)];
    fprintf(' Processing %s', basename);
    cat_section = do_process(conf, basename, min_magJ, max_magJ);
    starcat = [starcat; cat_section]; %#ok<AGROW>
    clear ('cat_section');
end

t2 = tic;
disp('Sorting...');
starcat = sortrows(starcat, [3 4 5 2 1]);
toc(t2);

fprintf('Subtotal ');
toc(t_init);

end



function catsect = do_process(conf, varname, min_mag, max_mag)
    t1 = tic;    
    fullname = [conf.PSC_mat_path varname '.mat'];
    load(fullname);
      % cataux = sortrows(psc_aaa.mat', 3);  3 is the column containing
      %                                      J magnitudes
    cataux = eval(['sortrows(' varname ''', 3);']);
    eval(['clear ' varname]);
    stars_to_use = ...
        ( (cataux(:,3) > min_mag) & (cataux(:,3) <= max_mag));
    catsect = cataux(stars_to_use, :);
    clear ('cataux');
    fprintf(' => '); 
    toc(t1);
end