function fluxref = Refmagx_Vega(band, Vegamag, bandName)
% Computes reference fluxes in passband 'band' using star Vega as a 
% reference.
%
% Copyright (C) 2016-2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

% Loads and processes spectral data for Vega (alpha Lyr:)
% File alpha_lyr_stis_008.fits downloaded on 2016-11-11 (yyyy-mm-dd) from
% http://www.stsci.edu/hst/observatory/crds/calspec.html (old website)
% This file is now available at: ftp://ftp.stsci.edu/cdbs/calspec/
% See file "calspec/readme.txt" for more information.

vega = read_calspec('calspec/alpha_lyr_stis_008.fits');
vega_lambda = vega{1};
vega_flux = vega{2};

% Numerically integrates energy flux from Vega
vega_lambdadif = filter([1 -1], 1, vega_lambda); %differentiates
vega_lambdadif(1) = 0;
vega_fluxint = filter(1, [1 -1], vega_flux .* vega_lambdadif); %integrates
vegaflux = vega_fluxint(end);
fprintf('Vega flux = %e erg/s/cm^2\n',vegaflux);

% Computes Vega's flux in band 'band'
B = interp1(band(:,1), band(:,2), vega_lambda, 'pchip', 0);
 %figure;
 %plot(vega_lambda, band); set(gca,'xscale','log'); grid on;
vega_fluxint = filter(1, [1 -1], vega_flux .* vega_lambdadif .* B);
vega_Bflux = vega_fluxint(end);
fprintf('Vega flux in band %s = %e erg/s/cm^2\n', bandName, vega_Bflux);

% Computes reference flux.
% Reference fluxes are the fluxes that set the zero point of the
% magnitude scales.
fluxref = vega_Bflux * 10^(0.4 * Vegamag);
fprintf('Reference flux in band %s => %e erg/s/cm^2\n', bandName, fluxref);

end

