% Script used to process the 2-MASS star catalog for the plotFig7.m script.
% Warning: This script may take many hours to complete!
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

% Notice: Since data associated with the 2-MASS star catalog is very large
% this script assumes that the 2MASS star catalog is stored in an external
% hard disk. You will need to adjust the path to the 2-MASS catalog and
% processed data (in 2mass/load_2mass_settings.m).

clear;
close all;

t1 = tic;

% Set this to true to get detailed report
verbose = true;

% If running GNU-Octave, sets default format to use in .mat files
setup_octave_savemat();

% Get configuration
p = path;
addpath('2mass');
conf = load_2mass_settings;
path(p);

catfile_path = conf.PSC_sortcat_path; 
	% Defined in ./2mass/load_2mass_settings.m
   
numsections = 20; % number of sections

basename1 = [catfile_path 'psc_JHK'];
basename2 = [catfile_path 'psc_HKJ'];
catfile_basenames = [basename1; basename2];
destfile = 'outputs/2MASS_out.mat';

for m=1:2
    for k=1:20
        catsection = sprintf('%s%.2d.mat', catfile_basenames(m, :), k);
        if exist(catsection, 'file') == false
            error(['Preprocessed catalog file section %s not found.\n'...
                'Read 2mass/01readme.txt for instructions in how '...
                'to generate it.'], catsection); %#ok<SPERR>
        end
    end
end

% Input parameters
inputparams.TwoMASSJHK_basename = 'f:/2mass/data/psc_JHK';
inputparams.TwoMASSHKJ_basename = 'f:/2mass/data/psc_HKJ';

disp('Starting catalog processing - this may take many hours.');

% Processing data from 2-MASS star catalog, using J-H color indexes.
disp ('Processing data from 2-MASS catalog, using J-H color indexes.');
outputs_JH = lower_bound_from_2mass('JH', inputparams, verbose);

% Processing data from 2-MASS star catalog, using J-Ks color indexes.
disp ('Processing data from 2-MASS catalog, using J-Ks color indexes.');
outputs_JK = lower_bound_from_2mass('JK', inputparams, verbose);

% Processing data from 2-MASS star catalog, using H-Ks color indexes.
disp ('Processing data from 2-MASS catalog, using H-Ks color indexes.');
outputs_HK = lower_bound_from_2mass('HK', inputparams, verbose);

save(destfile, 'outputs_JH', 'outputs_JK', 'outputs_HK');

dt1 = toc(t1);
fprintf('Script %s took %f seconds.\n', mfilename, dt1);
disp('Done.');
