% Script used to process the Hipparcos star catalog for the plotFig7.m
% script.
%
% Copyright (C) 2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

clear;
close all;

t1 = tic;
catfile_BVI = 'outputs/hipBVI.mat';
destfile = 'outputs/HippBVI_out.mat';

% If running GNU-Octave, sets default format to use in .mat files
setup_octave_savemat();

if exist(catfile_BVI, 'file') == false
    src_cat_file = 'hipparcos/hip_main.dat'; % Source star catalog.
    fprintf('Preprocessed Hipparcos catalog (file %s) not found!\n',...
        catfile_BVI);
    disp('Trying to generate it from the main Hipparcos Catalog.');
    
    % Check if the source catalog is available at the expected folder
    if exist(src_cat_file, 'file') == 0
        error(['File %s not found!\n' ...
            'Download hip_main.dat.gz from ' ...
            'ftp://cdsarc.u-strasbg.fr/pub/cats/I/239,\n' ...
            'unzip it to the "hipparcos/" folder and run this ' ...
            'script again.\n'], src_cat_file);
    end
    
    % Preprocessing star catalog
    disp('Preprocessing star catalog - This may take a while.')
    [HipBVI, badrows_HipBVI] = readHipparcos(src_cat_file);
    % Description of fields:
    %   HipBVI(:,1) => Hipparcos catalog numbers
    %   HipBVI(:,2) => Right Ascensions in degrees
    %   HipBVI(:,3) => Declinations in degrees
    %   HipBVI(:,4) => V magnitudes
    %   HipBVI(:,5) => B-V color indexes
    %   HipBVI(:,6) => V-I color indexes
    
    % Saving to file.
    fprintf('Saving star catalog to %s.\n', catfile_BVI);
    save(catfile_BVI, 'HipBVI', 'badrows_HipBVI');
    disp('Done star catalog preprocessing.');
else
    fprintf('Loading preprocessed Hipparcos catalog (file %s).\n',...
        catfile_BVI);
    load(catfile_BVI);
end

% Processing data from Hipparcos catalog, using B-V color indexes.
disp ('Processing data from Hipparcos catalog, using B-V color indexes.');
outputs_BV = lower_bound_from_starcat('HipBV');

% Processing data from Hipparcos catalog, using V-I color indexes.
disp ('Processing data from Hipparcos catalog, using V-I color indexes.');
outputs_VI = lower_bound_from_starcat('HipVI');

save(destfile, 'outputs_BV', 'outputs_VI');

dt1 = toc(t1);
fprintf('Script %s took %f seconds.\n', mfilename, dt1);
disp('Done.');
