function params = merge_input_params(input_params, default_params)
% params = merge_input_params(input_params, default_params)
% Merges structs input_params and default_params. 
% Fields in input_params have precedence. If there are fields in
% input_params missing in default_params these are not copied and a
% warning message is displayed.
%
% Copyright (C) 2017-2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

fnames = fieldnames(input_params);

% Checks for input parameters that are unused, printing a warning if some
% is found.  This is to protect the user against typos when assigning
% field values.
N = size(fnames, 1);
num_ignored = 0;
for k=1:N
    fieldname = fnames{k};
    if isfield(default_params, fieldname) == 0
        num_ignored = num_ignored + 1;
        listIgnored{num_ignored} = fieldname; %#ok<AGROW>
    end
end
if num_ignored > 0
    text = format_listIgnored(listIgnored, num_ignored);
    warning (['There are %d unused fields in input_params\n'...
        'List of ignored fields:\n'...
        '%s\n'...
        'Perhaps this happened because some of these input fields'...
        ' was mispelled. If not, you can avoid this warning by'...
        ' creating a copy of input_params without these fields with'...
        ' the "rmfield" command.'], num_ignored, text);
end

% Copy parameters from input_parameters or from defaults.
fnames = fieldnames(default_params);
N = size(fnames, 1);
for k=1:N
    fieldname = fnames{k};
    if isfield(input_params, fieldname)
        params.(fieldname) = input_params.(fieldname);
    else
        params.(fieldname) = default_params.(fieldname);
    end
end

end



function text = format_listIgnored(listIgnored, num_ignored)
% Helper function for merge_input_params
text = '';
for k=1:num_ignored
    text = [text, sprintf('  %s\n', listIgnored{k})]; %#ok<AGROW>
end
end
