function [x, badconv] = string2double(s)
% STRING2DOUBLE Converts a string to a scalar real value in double precision.
% [x, badconv] = STRING2DOUBLE(s)
% Inputs: s - string to be converted
% Outputs: x - converted value or NaN in case of errors.
%          badconv - true if there was an error in conversion.
%
% Copyright (C) 2017-2019 INPE - Instituto Nacional de Pesquisas Espaciais.
% This is free software - see file LICENSE.txt for terms and conditions.

% Code written by Marcio A. A. Fialho.

[aux, count, errmsg, nextidx] = sscanf(s, '%f', 1);

if count == 1 && isempty(errmsg) && nextidx > numel(s)
    badconv = false;
    x = aux;
else
    badconv = true;
    x = NaN;
end

end

